;*****************************************************************************
;				NICST TOOL
;
;  RC-5 Part 1 test for TEB bands. Calculates the retreived EV source radiance
;  and compares to specifications. Also, the detector uniformity is investigated.
;
;  Input:
;  1) Input file with paths to RVS, and general info sav files as well
;     as the .temp.sav, .dn.sav, .rad.sav, .rg.sav, and .snr.sav files.
;
;  Output:
;  1) rad_BCS_ret[collect,band,HAM,detector,subsample,ifit]
;  2) ARD[collect,band,HAM,detector,subsample,ifit]
;  3) RRU[collect,band,HAM,subsample,ifit]
;  4) mean_ARD[collect,band,HAM,subsample,ifit]
;  5) max_ARD[collect,band,HAM,subsample,ifit]
;  6) ARD_gc[collect,band,HAM,detector,subsample,ifit] -- ARD minus fitting residual
;  7) mean_ARD_gc[collect,band,HAM,subsample,ifit] -- mean ARD over detectors minus fitting residual
;  
;  v1.0 - 04/14/2008 - Jeff McIntire
;*****************************************************************************

PRO RC5_eff_rad, infile

;*****************************************************************************
;  Read in input file and sav TEB file.
;*****************************************************************************

nlines=File_Lines(infile)
ab=''
header=strarr(1)
inpath=strarr(1)		; Input path.
outpath=strarr(1)		; Output path.

openr,lun,infile,/Get_Lun	
readf,lun,header	
readf,lun,inpath
readf,lun,outpath
Free_Lun,lun

a2=strsplit(outpath,'/',/Extract)
a3=N_ELEMENTS(a2)

restore,'general.TEB.2.sav'
restore,outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.dn.sav'
restore,outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.rad.sav'
restore,outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.temp.sav'
restore,outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.rg.sav'
restore,outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.snr.sav'

outfile=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.eff_rad.sav'

;*****************************************************************************
;  Definitions
;*****************************************************************************

NEDT_spec=[[2.5,1.5,0.396,0.107,0.091,0.07,0.072,0.072],[0,0,0,0.423,0,0,0,0]]

fit_res=dblarr(ncollects,nbands,nham,maxdet,maxsubsets,6)

rad_BCS_ret=dblarr(ncollects,nbands,nham,maxdet,maxsubsets,6)
delta_rad_BCS_ret=dblarr(ncollects,nbands,nham,maxdet,maxsubsets,6)
mean_rad_BCS_ret=dblarr(ncollects,nbands,nham,maxsubsets,6)
max_rad_BCS_ret=dblarr(ncollects,nbands,nham,maxsubsets,6)
min_rad_BCS_ret=dblarr(ncollects,nbands,nham,maxsubsets,6)
std_rad_BCS_ret=dblarr(ncollects,nbands,nham,maxsubsets,6)
NEdL_det=dblarr(nbands,nham,maxdet,maxsubsets,2,2,2)

ARD=dblarr(ncollects,nbands,nham,maxdet,maxsubsets,6)
mean_ARD=dblarr(ncollects,nbands,nham,maxsubsets,6)
max_ARD=dblarr(ncollects,nbands,nham,maxsubsets,6)
std_ARD=dblarr(ncollects,nbands,nham,maxsubsets,6)
ARD_gc=dblarr(ncollects,nbands,nham,maxdet,maxsubsets,6)
mean_ARD_gc=dblarr(ncollects,nbands,nham,maxsubsets,6)

RRU=dblarr(ncollects,nbands,nham,maxsubsets,6,4)
RRU_det=dblarr(ncollects,nbands,nham,maxdet,maxsubsets,6,2)

;*****************************************************************************
;  Find retrived BCS radiance for RC5 part 1.
; ifit 0-2 for linear, quadratic, and cubic with no gain correction;
; ifit 3-5 for linear, quadratic, and cubic with gain correction
;*****************************************************************************

FOR ifit=0, 5 DO BEGIN
    FOR col=0, ncollects-1 DO BEGIN
        FOR b=0, nbands-1 DO BEGIN
            FOR is=0, subsets[b]-1 DO BEGIN
                FOR ih=0, nham-1 DO BEGIN
                    FOR id=0, detectors[b]-1 DO BEGIN
                        IF dn[col,b,ih,id,0,1,0] GT dn[col,b,ih,id,1,1,0] AND dn_obc[col,b,ih,id,0,1,0] GT dn_obc[col,b,ih,id,1,1,0] THEN BEGIN 
                            isubset=is
                        ENDIF ELSE BEGIN
                            IF is EQ 0 THEN isubset=1
                            IF is EQ 1 THEN isubset=0
                        ENDELSE

                        IF ifit EQ 0 THEN rad_BCS_ret[col,b,ih,id,is,ifit] $
                          =(rg_1[b,ih,id,is,0,ifit,0]+rg_1[b,ih,id,is,1,ifit,0]*dn[col,b,ih,id,is,1,0])/rvs[b,is,id,ih,0]/p[b] $
                          +(rvs[b,is,id,ih,1]/rvs[b,is,id,ih,0])*rad_p1[col,b,id,1] $
                          -(rvs[b,is,id,ih,1]-rvs[b,is,id,ih,0])/(rvs[b,is,id,ih,0]*p[b])*(rad_p2[col,b,ih,id,0]-(1-p[b])*rad_p2[col,b,ih,id,1])
                        IF ifit EQ 1 THEN rad_BCS_ret[col,b,ih,id,is,ifit] $
                          =(rg_1[b,ih,id,is,0,ifit,0]+rg_1[b,ih,id,is,1,ifit,0]*dn[col,b,ih,id,is,1,0]+rg_1[b,ih,id,is,2,ifit,0]*dn[col,b,ih,id,is,1,0]^2) $
                          /rvs[b,is,id,ih,0]/p[b] $
                          +(rvs[b,is,id,ih,1]/rvs[b,is,id,ih,0])*rad_p1[col,b,id,1] $
                          -(rvs[b,is,id,ih,1]-rvs[b,is,id,ih,0])/(rvs[b,is,id,ih,0]*p[b])*(rad_p2[col,b,ih,id,0]-(1-p[b])*rad_p2[col,b,ih,id,1])
                        IF ifit EQ 2 THEN rad_BCS_ret[col,b,ih,id,is,ifit] $
                          =(rg_1[b,ih,id,is,0,ifit,0]+rg_1[b,ih,id,is,1,ifit,0]*dn[col,b,ih,id,is,1,0]+rg_1[b,ih,id,is,2,ifit,0]*dn[col,b,ih,id,is,1,0]^2 $
                            +rg_1[b,ih,id,is,3,ifit,0]*dn[col,b,ih,id,is,1,0]^3)/rvs[b,is,id,ih,0]/p[b] $
                          +(rvs[b,is,id,ih,1]/rvs[b,is,id,ih,0])*rad_p1[col,b,id,1] $
                          -(rvs[b,is,id,ih,1]-rvs[b,is,id,ih,0])/(rvs[b,is,id,ih,0]*p[b])*(rad_p2[col,b,ih,id,0]-(1-p[b])*rad_p2[col,b,ih,id,1])
                        IF ifit EQ 3 THEN BEGIN
                            rad_BCS_ret[col,b,ih,id,is,ifit] $
                              =(rg_1[b,ih,id,is,0,0,0]+rg_1[b,ih,id,is,1,0,0]*dn[col,b,ih,id,is,1,0])/rvs[b,is,id,ih,0]/p[b] $
                              *(sig_mean(rad_OBC[col,b,ih,id,is,0:99],3,1)/(rg_1[b,ih,id,is,0,0,0]+rg_1[b,ih,id,is,1,0,0]*dn_obc[col,b,ih,id,isubset,1,0])) $
                              +(rvs[b,is,id,ih,1]/rvs[b,is,id,ih,0])*rad_p1[col,b,id,1] $
                              -(rvs[b,is,id,ih,1]-rvs[b,is,id,ih,0])/(rvs[b,is,id,ih,0]*p[b])*(rad_p2[col,b,ih,id,0]-(1-p[b])*rad_p2[col,b,ih,id,1])
                            fit_res[col,b,ih,id,is,ifit] $
                              =(rad_BCS[col,b,ih,id,is,0]-rg_1[b,ih,id,is,0,0,0]-rg_1[b,ih,id,is,1,0,0]*dn[col,b,ih,id,is,1,0])/rad_BCS[col,b,ih,id,is,0]*100
                        ENDIF
                        IF ifit EQ 4 THEN BEGIN
                            rad_BCS_ret[col,b,ih,id,is,ifit] $
                              =(rg_1[b,ih,id,is,0,1,0]+rg_1[b,ih,id,is,1,1,0]*dn[col,b,ih,id,is,1,0]+rg_1[b,ih,id,is,2,1,0]*dn[col,b,ih,id,is,1,0]^2)/rvs[b,is,id,ih,0]/p[b] $
                              *(sig_mean(rad_OBC[col,b,ih,id,is,0:99],3,1)/(rg_1[b,ih,id,is,0,1,0]+rg_1[b,ih,id,is,1,1,0]*dn_obc[col,b,ih,id,isubset,1,0] $
                                                                            +rg_1[b,ih,id,is,2,1,0]*dn_obc[col,b,ih,id,isubset,1,0]^2))  $
                              +(rvs[b,is,id,ih,1]/rvs[b,is,id,ih,0])*rad_p1[col,b,id,1] $
                              -(rvs[b,is,id,ih,1]-rvs[b,is,id,ih,0])/(rvs[b,is,id,ih,0]*p[b])*(rad_p2[col,b,ih,id,0]-(1-p[b])*rad_p2[col,b,ih,id,1])
                            fit_res[col,b,ih,id,is,ifit] $
                              =(rad_BCS[col,b,ih,id,is,0]-rg_1[b,ih,id,is,0,1,0]-rg_1[b,ih,id,is,1,1,0]*dn[col,b,ih,id,is,1,0] $
                                -rg_1[b,ih,id,is,2,1,0]*dn[col,b,ih,id,is,1,0]^2)/rad_BCS[col,b,ih,id,is,0]*100
                        ENDIF
                        IF ifit EQ 5 THEN BEGIN 
                            rad_BCS_ret[col,b,ih,id,is,ifit] $
                              =(rg_1[b,ih,id,is,0,2,0]+rg_1[b,ih,id,is,1,2,0]*dn[col,b,ih,id,is,1,0]+rg_1[b,ih,id,is,2,2,0]*dn[col,b,ih,id,is,1,0]^2 $
                                +rg_1[b,ih,id,is,3,2,0]*dn[col,b,ih,id,is,1,0]^3)/rvs[b,is,id,ih,0]/p[b] $
                              *(sig_mean(rad_OBC[col,b,ih,id,is,0:99],3,1)/(rg_1[b,ih,id,is,0,2,0]+rg_1[b,ih,id,is,1,2,0]*dn_obc[col,b,ih,id,isubset,1,0] $
                                                                            +rg_1[b,ih,id,is,2,2,0]*dn_obc[col,b,ih,id,isubset,1,0]^2 $
                                                                            +rg_1[b,ih,id,is,3,2,0]*dn_obc[col,b,ih,id,isubset,1,0]^3)) $
                              +(rvs[b,is,id,ih,1]/rvs[b,is,id,ih,0])*rad_p1[col,b,id,1] $
                              -(rvs[b,is,id,ih,1]-rvs[b,is,id,ih,0])/(rvs[b,is,id,ih,0]*p[b])*(rad_p2[col,b,ih,id,0]-(1-p[b])*rad_p2[col,b,ih,id,1])
                            fit_res[col,b,ih,id,is,ifit] $
                              =(rad_BCS[col,b,ih,id,is,0]-rg_1[b,ih,id,is,0,2,0]-rg_1[b,ih,id,is,1,2,0]*dn[col,b,ih,id,is,1,0] $
                                -rg_1[b,ih,id,is,2,2,0]*dn[col,b,ih,id,is,1,0]^2-rg_1[b,ih,id,is,3,2,0]*dn[col,b,ih,id,is,1,0]^3)/rad_BCS[col,b,ih,id,is,0]*100
                        ENDIF

;*****************************************************************************
;  Caclulate the ARD.
;*****************************************************************************

                        ARD[col,b,ih,id,is,ifit]=100*(rad_BCS_ret[col,b,ih,id,is,ifit]/rad_p1[col,b,id,0]-1.)
                        ARD_gc[col,b,ih,id,is,ifit]=ARD[col,b,ih,id,is,ifit]+fit_res[col,b,ih,id,is,ifit]

                        delta_rad_BCS_ret[col,b,ih,id,is,ifit]=rad_BCS_ret[col,b,ih,id,is,ifit]-rad_p1[col,b,id,0]
                        NEdL_det[b,ih,id,is,0,1,0]=rad_BCS[col,b,ih,id,is,0]/SNR[col,b,ih,id,is,1]
                    ENDFOR

                    mean_rad_BCS_ret[col,b,ih,is,ifit]=sig_mean(delta_rad_BCS_ret[col,b,ih,0:detectors[b]-1,is,ifit],3,1)
                    max_rad_BCS_ret[col,b,ih,is,ifit]=max(delta_rad_BCS_ret[col,b,ih,0:detectors[b]-1,is,ifit],min=min_rad)
                    min_rad_BCS_ret[col,b,ih,is,ifit]=min_rad
                    std_rad_BCS_ret[col,b,ih,is,ifit]=sig_mean(delta_rad_BCS_ret[col,b,ih,0:detectors[b]-1,is,ifit],3,2)
                    mean_ARD[col,b,ih,is,ifit]=sig_mean(ARD[col,b,ih,0:detectors[b]-1,is,ifit],3,1)
                    mean_ARD_gc[col,b,ih,is,ifit]=sig_mean(ARD_gc[col,b,ih,0:detectors[b]-1,is,ifit],3,1)
                    max_ARD[col,b,ih,is,ifit]=max(abs(ARD[col,b,ih,0:detectors[b]-1,is,ifit]))
                    std_ARD[col,b,ih,is,ifit]=sig_mean(ARD[col,b,ih,0:detectors[b]-1,is,ifit],3,2)
                                        
;*****************************************************************************
;  Calculate the RRU using both retrieved and delta retrieved as
;  well as both NEdL at spec and measured NEdL
;*****************************************************************************

                    temp1=mean(rad_BCS_ret[col,b,ih,0:detectors[b]-1,is,ifit])
                    RRU[col,b,ih,is,ifit,0]=max(abs(rad_BCS_ret[col,b,ih,0:detectors[b]-1,is,ifit]-temp1))/(NEdT_spec[b,0]*Planck_deriv(T_bcs[col],lambda_center[b]))
                    RRU[col,b,ih,is,ifit,1]=max(abs(rad_BCS_ret[col,b,ih,0:detectors[b]-1,is,ifit]-temp1))/mean(NEdL_det[b,ih,0:detectors[b]-1,is,0,1,0])
                    RRU[col,b,ih,is,ifit,2]=max(abs(delta_rad_BCS_ret[col,b,ih,0:detectors[b]-1,is,ifit]-mean_rad_BCS_ret[col,b,ih,is,ifit])) $
                      /(NEdT_spec[b,0]*Planck_deriv(T_bcs[col],lambda_center[b]))
                    RRU[col,b,ih,is,ifit,3]=max(abs(delta_rad_BCS_ret[col,b,ih,0:detectors[b]-1,is,ifit]-mean_rad_BCS_ret[col,b,ih,is,ifit])) $
                      /mean(NEdL_det[b,ih,0:detectors[b]-1,is,0,1,0])

                    ; Calculate the RRU per detector.
                    temp=mean(delta_rad_BCS_ret[col,b,ih,0:detectors[b]-1,is,ifit])
                    RRU_det[col,b,ih,0:detectors[b]-1,is,ifit,0]=abs(delta_rad_BCS_ret[col,b,ih,0:detectors[b]-1,is,ifit]-temp) $
                      /(NEdT_spec[b,0]*Planck_deriv(T_bcs[col],lambda_center[b]))
                    RRU_det[col,b,ih,0:detectors[b]-1,is,ifit,0]=abs(rad_BCS_ret[col,b,ih,0:detectors[b]-1,is,ifit]-temp1) $
                      /(NEdT_spec[b,0]*Planck_deriv(T_bcs[col],lambda_center[b]))
                    RRU_det[col,b,ih,0:detectors[b]-1,is,ifit,1]=abs(delta_rad_BCS_ret[col,b,ih,0:detectors[b]-1,is,ifit]-temp) $
                      /NEdL_det[b,ih,0:detectors[b]-1,is,0,1,0]
                ENDFOR
            ENDFOR
        ENDFOR
    ENDFOR
ENDFOR

;*****************************************************************************
;  Save data on ARD and RRU to dat file.
;*****************************************************************************

outfile2=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.ard.txt'
outfile3=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.ard.gc.txt'
outfile4=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.rru.txt'
outfile5=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.rru.gc.txt'

fmt_1='(i2, 5x, i3, 5x, i2, 5x, f, 5x, f, 5x, f, 5x, f, 5x, f, 5x, f, 5x, f, 5x, f)'

openw,lun,outfile2,/get_lun
printf,lun,'Worst case Absolute Radiance Difference (ARD) no gain correction'
printf,lun,'Collect     Temp       HAM      I4        I5       M12       M13        M14      M15      M16A      M16B'
FOR ih=0, nham-1 DO BEGIN
    FOR col=0, ncollects-1 DO BEGIN
        printf,lun,format=fmt_1,col,T_bcs[col],ih,mean(mean_ARD[col,0,ih,*,1]),mean(mean_ARD[col,1,ih,*,1]), $
          mean_ARD[col,2,ih,0,1],mean_ARD[col,3,ih,0,1],mean_ARD[col,4,ih,0,1],mean_ARD[col,5,ih,0,1],mean_ARD[col,6,ih,0,1],mean_ARD[col,7,ih,0,1]
    ENDFOR
ENDFOR
free_lun,lun

openw,lun,outfile3,/get_lun
printf,lun,'Worst case Absolute Radiance Difference (ARD) gain correction'
printf,lun,'Collect     Temp       HAM      I4        I5       M12       M13        M14      M15      M16A      M16B'
FOR ih=0, nham-1 DO BEGIN
    FOR col=0, ncollects-1 DO BEGIN
        printf,lun,format=fmt_1,col,T_bcs[col],ih,mean(mean_ARD[col,0,ih,*,4]),mean(mean_ARD[col,1,ih,*,4]), $
          mean_ARD[col,2,ih,0,4],mean_ARD[col,3,ih,0,4],mean_ARD[col,4,ih,0,4],mean_ARD[col,5,ih,0,4],mean_ARD[col,6,ih,0,4],mean_ARD[col,7,ih,0,4]
    ENDFOR
ENDFOR
free_lun,lun

openw,lun,outfile4,/get_lun
printf,lun,'Worst case Relative Response Uniformity (RRU) no gain correction'
printf,lun,'Collect     Temp       HAM      I4        I5       M12       M13        M14      M15      M16A      M16B'
FOR ih=0, nham-1 DO BEGIN
    FOR col=0, ncollects-1 DO BEGIN
        printf,lun,format=fmt_1,col,T_bcs[col],ih,mean(RRU[col,0,ih,*,1,0]),mean(RRU[col,1,ih,*,1,0]), $
          RRU[col,2,ih,0,1,0],RRU[col,3,ih,0,1,0],RRU[col,4,ih,0,1,0],RRU[col,5,ih,0,1,0],RRU[col,6,ih,0,1,0],RRU[col,7,ih,0,1,0]
    ENDFOR
ENDFOR
free_lun,lun

openw,lun,outfile5,/get_lun
printf,lun,'Worst case Relative Response Uniformity (RRU) gain correction'
printf,lun,'Collect     Temp       HAM      I4        I5       M12       M13        M14      M15      M16A      M16B'
FOR ih=0, nham-1 DO BEGIN
    FOR col=0, ncollects-1 DO BEGIN
        printf,lun,format=fmt_1,col,T_bcs[col],ih,mean(RRU[col,0,ih,*,4,0]),mean(RRU[col,1,ih,*,4,0]), $
          RRU[col,2,ih,0,4,0],RRU[col,3,ih,0,4,0],RRU[col,4,ih,0,4,0],RRU[col,5,ih,0,4,0],RRU[col,6,ih,0,4,0],RRU[col,7,ih,0,4,0]
    ENDFOR
ENDFOR
free_lun,lun
close,lun,/file,/all

save,/compress,rad_BCS_ret,ARD,ARD_gc,max_ARD,mean_ARD,mean_ARD,RRU,filename=outfile

;*****************************************************************************
;  Plot the ARD.
;*****************************************************************************

set_multicolor,xsave,ysave,psave,chname,lcol,symbol,red,green,blue
set_plot,'ps'
outfname=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.ard.gain_correction.ps'
device,/landscape,filename=outfname,/color
!p.multi=[0,1,1]
!p.position=0

ARD_req_I=[5,2.5]
ARD_req_M=[[0,0,12.3,2.1,1.6,1.6],[7.0,5.7,2.4,0.60,.60,.60],[0.7,0.7,0.6,0.4,0.4,0.4], $
	[0.7,0.7,0.4,0.4,0.4,0.4],[0.7,0.7,0.5,0.4,0.4,0.4]]
ARD_req_temp=[190.,230.,270.,310.,340.]

G=findgen(30)
FOR b=0, nbands-1 DO BEGIN
    title1='Absolute Radiance Difference, (SRV0545)'
    title2=band_name[b]+' (quadratic poly_fit)'
    
    ymax=max(ARD[0:ncollects-1,b,0,0:detectors[b]-1,0,4],min=ymin)
    
    plot,T_bcs[0:ncollects-1],ARD[0:ncollects-1,b,0,0,0,4],xtit='BCS Temperature (K)',ytit='ARD',yrange=[-1,1], $
      xrange=[190.,350.],title=title2,charsize=1.2,charthick=5,/nodata
    
    FOR id=0,detectors[b]-1 DO BEGIN
        oplot,T_bcs[0:ncollects-1],ARD[0:ncollects-1,b,0,id,0,4],symsize=1,color=lcol[id],psym=symbol[id]
        oplot,T_bcs[0:ncollects-1],ARD[0:ncollects-1,b,0,id,0,4],color=lcol[id]
    ENDFOR
    IF band_type[b] NE 1 THEN oplot,ARD_req_temp[0:4],ARD_req_M[b-2,0:4],color=lcol[1],linestyle=2,thick=3
    IF band_type[b] NE 1 THEN oplot,ARD_req_temp[0:4],-ARD_req_M[b-2,0:4],color=lcol[1],linestyle=2,thick=3
    IF band_type[b] NE 1 AND b LT 4 THEN oplot,ARD_req_temp[1:4],ARD_req_M[b-2,1:4],color=lcol[1],linestyle=2,thick=3
    IF band_type[b] NE 1 AND b LT 4 THEN oplot,ARD_req_temp[1:4],-ARD_req_M[b-2,1:4],color=lcol[1],linestyle=2,thick=3

    XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
    IF band_type[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
    IF band_type[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
ENDFOR

plot,T_bcs[0:ncollects-1],mean_ARD[0:ncollects-1,0,0,0,1],xtit='BCS Temperature (K)',ytit='ARD',yrange=[-1,1], $
  xrange=[190.,350.],charsize=1.2,charthick=5,/nodata
FOR b=0, nbands-1 DO BEGIN
    oplot,T_bcs[0:ncollects-1],mean_ARD[0:ncollects-1,b,0,0,4],symsize=1,color=lcol[b],psym=symbol[b]
    oplot,T_bcs[0:ncollects-1],mean_ARD[0:ncollects-1,b,0,0,4],color=lcol[b]
ENDFOR
XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
set_legend,1,band_name,lcol,symbol

;*****************************************************************************
;  Plot the RRU.
;*****************************************************************************

title1='Relative Response Uniformity, (SRV0613)'
;T_max_9=[349.6,330.8,349.6,339.5,329.2,334.1,330.4,330.4]
T_max_9=[317.7,306.,317.7,308.7,302.4,308.7,306.,306.]

ymax=max(RRU[0:ncollects-1,0:nbands-1,0,0,4,0])

plot,T_bcs[0:ncollects-1],RRU[0:ncollects-1,0,0,0,4,0],xtit='BCS Temperature (K)',ytit='RRU (gain correction)', $
  yrange=[0,max(RRU[0:ncollects-1,*,0,0,4,0])],xrange=[190.,350.],charsize=1.2,charthick=5,/nodata
FOR b=0, nbands-1 DO BEGIN
    zz=WHERE(T_bcs[*] GT T_min[b,0] AND T_bcs[*] LT T_max_9[b],arr1)
    oplot,T_bcs[zz],RRU[zz,b,0,0,4,0],symsize=1,color=lcol[b],psym=symbol[b]
    oplot,T_bcs[zz],RRU[zz,b,0,0,4,0],color=lcol[b]
ENDFOR
XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
set_legend,1,band_name,lcol,symbol

FOR b=0, nbands-1 DO BEGIN
    ymax=max(RRU_det[0:ncollects-1,b,0,0:detectors[b]-1,0,4,0])

    plot,T_bcs[0:ncollects-1],RRU_det[0:ncollects-1,b,0,0,0,4,0],xtit='BCS Temperature (K)',ytit='RRU (gain correction)', $
      yrange=[0,ymax],xrange=[190.,350.],title=band_name[b],charsize=1.2,charthick=5,/nodata
    
    zz=WHERE(T_bcs[*] GT T_min[b,0] AND T_bcs[*] LT T_max_9[b],arr1)
    FOR id=0, detectors[b]-1 DO BEGIN
        oplot,T_bcs[zz],RRU_det[zz,b,0,id,0,4,0],symsize=1,color=lcol[id],psym=symbol[id]
        oplot,T_bcs[zz],RRU_det[zz,b,0,id,0,4,0],color=lcol[id]
    ENDFOR
    XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
    IF band_type[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
    IF band_type[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
ENDFOR

device,/close


END
