;*****************************************************************************
;				NICST TOOL
;
;  RC5 Part 1 graphs the delta BCS radiance versus dn, SNR vs delta BCS radiance
;  and NEdT vs delta BCS radiance.
;
;  Output:
;  1) postscript file containing graphs.
;  
;  v1.0 - 04/02/2008 - Jeff McIntire
;*****************************************************************************

PRO RC5_view, infile

close,/all

;*****************************************************************************
;  Read in data.
;*****************************************************************************

nlines=File_Lines(infile)
ab=''
header=strarr(1)
inpath=strarr(1)		; Input path.
outpath=strarr(1)		; Output path.

openr,lun,infile,/Get_Lun	
readf,lun,header	
readf,lun,inpath
readf,lun,outpath
Free_Lun,lun

a2=strsplit(outpath,'/',/Extract)
a3=N_ELEMENTS(a2)

restore,'general.TEB.2.sav'
restore,outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.rad.sav'
restore,outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.dn.sav'
restore,outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.rg.sav'
restore,outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.snr.sav'

;*****************************************************************************
;  Some definitions.
;*****************************************************************************

D=findgen(4000)
E=findgen(30000)
F=fltarr(30000)
HAM=['A','B']
SS=[' SS1',' SS2']
HAM_SS=['HAM A, SS1','HAM B, SS1','HAM A, SS2','HAM B, SS2'] 

;*****************************************************************************
;  Plot coefficients versus detector (from calibration equation).
;*****************************************************************************

set_multicolor,xsave,ysave,psave,chname,lcol,symbol,red,green,blue
set_plot,'ps'
outfname=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.coeff.ps'
device,/landscape,filename=outfname,/color

; Plot all bands on one page, then 4 bands to a page.
FOR i=0, 1 DO BEGIN
    IF i EQ 0 THEN !p.multi=[0,3,3]
    IF i EQ 1 THEN !p.multi=[0,2,2]
    !p.position=0
        
    ; Plot a0.
    FOR b=0, nbands-1 DO BEGIN
        title1='Detector Variation in a0'
        title2=band_name[b]+' (quadratic poly_fit)'
        
        ymax=max(rg_1[b,0:1,0:detectors[b]-1,0:subsets[b]-1,0,1,0],min=ymin)
        
        plot,D[0:detectors[b]-1]+1,rg_1[b,0,0:detectors[b]-1,0,0,1,0],yrange=[ymin,ymax],xrange=[0,detectors[b]], $
          xtit='Detector',ytit='a0',title=title2,charsize=1.2,charthick=5,thick=3,/nodata
        j=0
        FOR is=0, subsets[b]-1 DO BEGIN
            FOR ih=0, nham-1 DO BEGIN
                oplot,D[0:detectors[b]-1]+1,rg_1[b,ih,0:detectors[b]-1,is,0,1,0],symsize=1,color=lcol[j],psym=symbol[j],thick=3
                oplot,D[0:detectors[b]-1]+1,rg_1[b,ih,0:detectors[b]-1,is,0,1,0],color=lcol[j],thick=3
                j=j+1
            ENDFOR
        ENDFOR
        XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
        set_legend,1,HAM_SS,lcol,symbol
    ENDFOR
    
    IF i EQ 0 THEN !p.multi=[0,3,3]
    IF i EQ 1 THEN !p.multi=[0,2,2]
    !p.position=0
    
    ; Plot 1/a1.
    FOR b=0, nbands-1 DO BEGIN
        title1='Detector Variation in Gain (1/a1)'
        title2=band_name[b]+' (quadratic poly_fit)'
        
        ymax=max(1/rg_1[b,0:1,0:detectors[b]-1,0:subsets[b]-1,1,1,0],min=ymin)
        
        plot,D[0:detectors[b]-1]+1,1/rg_1[b,0,0:detectors[b]-1,0,1,1,0],yrange=[ymin,ymax],xrange=[0,detectors[b]], $
          xtit='Detector',ytit='Gain (1/a1)',title=title2,charsize=1.2,charthick=5,thick=3,/nodata
        j=0
        FOR is=0, subsets[b]-1 DO BEGIN
            FOR ih=0, nham-1 DO BEGIN
                oplot,D[0:detectors[b]-1]+1,1/rg_1[b,ih,0:detectors[b]-1,is,1,1,0],symsize=1,color=lcol[j],psym=symbol[j],thick=3
                oplot,D[0:detectors[b]-1]+1,1/rg_1[b,ih,0:detectors[b]-1,is,1,1,0],color=lcol[j],thick=3
                j=j+1
            ENDFOR
        ENDFOR
        XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
        set_legend,1,HAM_SS,lcol,symbol
    ENDFOR
    
    IF i EQ 0 THEN !p.multi=[0,3,3]
    IF i EQ 1 THEN !p.multi=[0,2,2]
    !p.position=0
    
    ; Plot a2.
    FOR b=0, nbands-1 DO BEGIN
        title1='Detector Variation in a2'
        title2=band_name[b]+' (quadratic poly_fit)'
        
        ymax=max(rg_1[b,0:1,0:detectors[b]-1,0:subsets[b]-1,2,1,0],min=ymin)
        
        plot,D[0:detectors[b]-1]+1,rg_1[b,0,0:detectors[b]-1,0,2,1,0],yrange=[ymin,ymax],xrange=[0,detectors[b]], $
          xtit='Detector',ytit='a2',title=title2,charsize=1.2,charthick=5,thick=3,/nodata
        j=0
        FOR is=0, subsets[b]-1 DO BEGIN
            FOR ih=0, nham-1 DO BEGIN
                oplot,D[0:detectors[b]-1]+1,rg_1[b,ih,0:detectors[b]-1,is,2,1,0],symsize=1,color=lcol[j],psym=symbol[j],thick=3
                oplot,D[0:detectors[b]-1]+1,rg_1[b,ih,0:detectors[b]-1,is,2,1,0],color=lcol[j],thick=3
                j=j+1
            ENDFOR
        ENDFOR
        XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
        set_legend,1,HAM_SS,lcol,symbol
    ENDFOR
ENDFOR

device,/close

;*****************************************************************************
;  Plot delta BCS radiance versus dn with fit (quadratic pol_fit)
;  along with the fractional fitting residual.
;*****************************************************************************

set_multicolor,xsave,ysave,psave,chname,lcol,symbol,red,green,blue
set_plot,'ps'
outfname=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.fits_1.ps'
device,/landscape,filename=outfname,/color

; Calibration equation.
; Plot all bands on one page, then one band to a page with residual.
title1='dL_BCS vs dn'
FOR ih=0, nham-1 DO BEGIN
    FOR i=0, 1 DO BEGIN
        IF i EQ 0 THEN !p.multi=[0,3,3]
        IF i EQ 1 THEN !p.multi=[0,1,2]
        !p.position=0

        ; Plot dn vs dL_BCS.
        FOR b=0, nbands-1 DO BEGIN
            IF band_type[b] EQ 0 THEN title2=band_name[b]+', HAM= '+HAM[ih]+' (quadratic poly_fit)'
            IF band_type[b] EQ 1 THEN title2=band_name[b]+' SS1, HAM= '+HAM[ih]+' (quadratic poly_fit)'
            
            ymax=max(rad_BCS[*,b,ih,*,0,0])
            xmax=max(dn[*,b,ih,*,0,1,0])
            
            plot,dn[*,b,ih,1,0,1,0],rad_BCS[*,b,ih,1,0,0],yrange=[0,ymax],xrange=[0,xmax], $
              ytit='dL_BCS (Wm-2sr-1um-1)',xtit='dn',title=title2,charsize=1.2,charthick=5,thick=3,/nodata
            
            FOR id=0, detectors[b]-1 DO BEGIN
                oplot,dn[*,b,ih,id,0,1,0],rad_BCS[*,b,ih,id,0,0],symsize=1,color=lcol[id],psym=symbol[id],thick=3
                oplot,rg_1[b,ih,id,0,0,1,0]+rg_1[b,ih,id,0,1,1,0]*D+rg_1[b,ih,id,0,2,1,0]*D^2,color=lcol[id],thick=3
            ENDFOR
            oplot,[-100,10000],[L_max[b,0],L_max[b,0]],symsize=1,color=lcol[1],linestyle=2,thick=3
            oplot,[-100,10000],[L_typ[b,0],L_typ[b,0]],symsize=1,color=lcol[2],linestyle=2,thick=3
            oplot,[-100,10000],[L_min[b,0],L_min[b,0]],symsize=1,color=lcol[3],linestyle=2,thick=3
            
            XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5

            ; Plot fractional fitting residual in percent.
            IF i EQ 1 THEN BEGIN
                ymax=max(100.*dL_fit[*,b,ih,0:detectors[b]-1,0,1,0],min=ymin)
                
                plot,rad_BCS[*,b,ih,0,is,0],100.*dL_fit[*,b,ih,0,0,1,0],xtit='dL_BCS (Wm-2sr-1um-1)',ytit='Radiance Residual (%)', $
                  xrange=[0,L_max[b,0]],yrange=[ymin,ymax],title=title1,charsize=1.2,charthick=5,thick=3,/nodata
                
                FOR id=0, detectors[b]-1 DO BEGIN
                    oplot,rad_BCS[*,b,ih,id,0,0],100.*dL_fit[*,b,ih,id,0,1,0],symsize=1,color=lcol[id],psym=symbol[id],thick=3
                    oplot,rad_BCS[*,b,ih,id,0,0],100.*dL_fit[*,b,ih,id,0,1,0],color=lcol[id],thick=3
                ENDFOR
                oplot,[L_max[b,0],L_max[b,0]],[-100,10000],symsize=1,color=lcol[1],linestyle=2,thick=3
                oplot,[L_typ[b,0],L_typ[b,0]],[-100,10000],symsize=1,color=lcol[2],linestyle=2,thick=3
                oplot,[L_min[b,0],L_min[b,0]],[-100,10000],symsize=1,color=lcol[3],linestyle=2,thick=3

                XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
                IF band_type[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
                IF band_type[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
            ENDIF
        ENDFOR
    ENDFOR
ENDFOR

; Response equation.
; Plot all bands on one page, then one band to a page with residual.
title1='dn vs dL_BCS'
FOR ih=0, nham-1 DO BEGIN
    FOR i=0, 1 DO BEGIN
        IF i EQ 0 THEN !p.multi=[0,3,3]
        IF i EQ 1 THEN !p.multi=[0,1,2]
        !p.position=0

        ; Plot dn vs dL_BCS.
        FOR b=0, nbands-1 DO BEGIN
            IF band_type[b] EQ 0 THEN title2=band_name[b]+', HAM= '+HAM[ih]+' (quadratic poly_fit)'
            IF band_type[b] EQ 1 THEN title2=band_name[b]+' SS1, HAM= '+HAM[ih]+' (quadratic poly_fit)'
            
            xmax=max(rad_BCS[*,b,ih,*,0,0])
            ymax=max(dn[*,b,ih,*,0,1,0])
            
            plot,rad_BCS[*,b,ih,1,0,0],dn[*,b,ih,1,0,1,0],yrange=[0,ymax],xrange=[0,xmax], $
              xtit='dL_BCS (Wm-2sr-1um-1)',ytit='dn',title=title2,charsize=1.2,charthick=5,thick=3,/nodata
            
            FOR id=0, detectors[b]-1 DO BEGIN
                oplot,rad_BCS[*,b,ih,id,0,0],dn[*,b,ih,id,0,1,0],symsize=1,color=lcol[id],psym=symbol[id],thick=3
                oplot,rg_1[b,ih,id,0,0,4,0]+rg_1[b,ih,id,0,1,4,0]*D+rg_1[b,ih,id,0,2,4,0]*D^2,color=lcol[id],thick=3
            ENDFOR
            oplot,[L_max[b,0],L_max[b,0]],[-100,10000],symsize=1,color=lcol[1],linestyle=2,thick=3
            oplot,[L_typ[b,0],L_typ[b,0]],[-100,10000],symsize=1,color=lcol[2],linestyle=2,thick=3
            oplot,[L_min[b,0],L_min[b,0]],[-100,10000],symsize=1,color=lcol[3],linestyle=2,thick=3
            
            XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5

            ; Plot fractional fitting residual in percent.
            IF i EQ 1 THEN BEGIN
                ymax=max(100.*dL_fit[*,b,ih,0:detectors[b]-1,0,4,0]/dn[*,b,ih,0:detectors[b]-1,0,1,0],min=ymin)
                
                plot,rad_BCS[*,b,ih,0,is,0],dL_fit[*,b,ih,0,0,4,0],xtit='dL_BCS (Wm-2sr-1um-1)',ytit='dn Residual (%)', $
                  xrange=[0,L_max[b,0]],yrange=[ymin,ymax],title=title1,charsize=1.2,charthick=5,thick=3,/nodata
                
                FOR id=0, detectors[b]-1 DO BEGIN
                    oplot,rad_BCS[*,b,ih,id,0,0],100.*dL_fit[*,b,ih,id,0,4,0]/dn[*,b,ih,id,0,1,0],symsize=1,color=lcol[id],psym=symbol[id],thick=3
                    oplot,rad_BCS[*,b,ih,id,0,0],100.*dL_fit[*,b,ih,id,0,4,0]/dn[*,b,ih,id,0,1,0],color=lcol[id],thick=3
                ENDFOR
                oplot,[L_max[b,0],L_max[b,0]],[-100,10000],symsize=1,color=lcol[1],linestyle=2,thick=3
                oplot,[L_typ[b,0],L_typ[b,0]],[-100,10000],symsize=1,color=lcol[2],linestyle=2,thick=3
                oplot,[L_min[b,0],L_min[b,0]],[-100,10000],symsize=1,color=lcol[3],linestyle=2,thick=3

                XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
                IF band_type[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
                IF band_type[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
            ENDIF
        ENDFOR
    ENDFOR
ENDFOR

device,/close

;*****************************************************************************
;  Plot delta BCS radiance versus dn with fits (linear poly_fit, quadratic pol_fit,
;  and cubic poly_fit).
;*****************************************************************************

set_multicolor,xsave,ysave,psave,chname,lcol,symbol,red,green,blue
set_plot,'ps'
outfname=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.fits_2.ps'
device,/landscape,filename=outfname,/color

title=strarr(4)

!p.multi=[0,2,3]

; Calibration equation.
FOR b=0, nbands-1 DO BEGIN
    !p.position=0

    FOR is=0, subsets[b]-1 DO BEGIN
        FOR ih=0, nham-1 DO BEGIN
            IF band_type[b] EQ 0 THEN BEGIN
                title1=band_name[b]+': dL_BCS vs dn'
                title[0]=band_name[b]+', HAM= '+HAM[ih]+' (linear poly_fit)'
                title[1]=band_name[b]+', HAM= '+HAM[ih]+' (quadratic poly_fit)'
                title[2]=band_name[b]+', HAM= '+HAM[ih]+' (cubic poly_fit)'
            ENDIF
            IF band_type[b] EQ 1 THEN BEGIN
                title1=band_name[b]+SS[is]+': dL_BCS vs dn'
                title[0]=band_name[b]+SS[is]+', '+'HAM= '+HAM[ih]+' (linear poly_fit)'
                title[1]=band_name[b]+SS[is]+', '+'HAM= '+HAM[ih]+' (quadratic poly_fit)'
                title[2]=band_name[b]+SS[is]+', '+'HAM= '+HAM[ih]+' (cubic poly_fit)'
            ENDIF
            
            ; Plot dL_BCS vs dn.
            ymax=max(L_max[b,0])
            xmax=max(dn[*,b,ih,*,is,1,0])
            
            FOR j=0, 2 DO BEGIN
                plot,dn[*,b,ih,1,is,1,0],rad_BCS[*,b,ih,1,is,0],yrange=[0,ymax],xrange=[0,xmax], $
                  ytit='dL_BCS (Wm-2sr-1um-1)',xtit='dn',title=title[j],charsize=1.2,charthick=5,thick=3,/nodata
                
                FOR id=0, detectors[b]-1 DO BEGIN
                    oplot,dn[*,b,ih,id,is,1,0],rad_BCS[*,b,ih,id,is,0],symsize=1,color=lcol[id],psym=symbol[id],thick=3
                    IF j EQ 0 THEN oplot,rg_1[b,ih,id,is,0,j,0]+rg_1[b,ih,id,is,1,j,0]*D,color=lcol[id],thick=3
                    IF j EQ 1 THEN oplot,rg_1[b,ih,id,is,0,j,0]+rg_1[b,ih,id,is,1,j,0]*D $
                      +rg_1[b,ih,id,is,2,j,0]*D^2,color=lcol[id],thick=3
                    IF j EQ 2 THEN oplot,rg_1[b,ih,id,is,0,j,0]+rg_1[b,ih,id,is,1,j,0]*D $
                      +rg_1[b,ih,id,is,2,j,0]*D^2+rg_1[b,ih,id,is,3,j,0]*D^3,color=lcol[id],thick=3
                ENDFOR
                oplot,[-100,10000],[L_max[b,0],L_max[b,0]],symsize=1,color=lcol[1],linestyle=2,thick=3
                oplot,[-100,10000],[L_typ[b,0],L_typ[b,0]],symsize=1,color=lcol[2],linestyle=2,thick=3
                oplot,[-100,10000],[L_min[b,0],L_min[b,0]],symsize=1,color=lcol[3],linestyle=2,thick=3
                
                ; Plot fractional fitting residual in percent.
                xmax2=max(L_max[b,0])
                ymax3=max(100.*dL_fit[*,b,ih,0:detectors[b]-1,0,j,0],min=ymin3)
                
                plot,rad_BCS[*,b,ih,0,is,0],100.*dL_fit[*,b,ih,0,is,j,0],xtit='dL_BCS (Wm-2sr-1um-1)',ytit='Radiance Residual (%)', $
                  xrange=[0,xmax2],yrange=[ymin3,ymax3],title=title[j],charsize=1.2,charthick=5,thick=3,/nodata
                
                FOR id=0, detectors[b]-1 DO BEGIN
                    oplot,rad_BCS[*,b,ih,id,is,0],100.*dL_fit[*,b,ih,id,is,j,0],symsize=1,color=lcol[id],psym=symbol[id],thick=3
                    oplot,rad_BCS[*,b,ih,id,is,0],100.*dL_fit[*,b,ih,id,is,j,0],color=lcol[id],thick=3
                ENDFOR
                oplot,[L_max[b,0],L_max[b,0]],[-100,10000],symsize=1,color=lcol[1],linestyle=2,thick=3
                oplot,[L_typ[b,0],L_typ[b,0]],[-100,10000],symsize=1,color=lcol[2],linestyle=2,thick=3
                oplot,[L_min[b,0],L_min[b,0]],[-100,10000],symsize=1,color=lcol[3],linestyle=2,thick=3
            ENDFOR
            XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
            IF band_type[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
            IF band_type[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
        ENDFOR
    ENDFOR
ENDFOR

; Response equation.
FOR b=0, nbands-1 DO BEGIN
    !p.position=0

    FOR is=0, subsets[b]-1 DO BEGIN
        FOR ih=0, nham-1 DO BEGIN
            IF band_type[b] EQ 0 THEN BEGIN
                title1=band_name[b]+': dn vs dL_BCS'
                title[0]=band_name[b]+', HAM= '+HAM[ih]+' (linear poly_fit)'
                title[1]=band_name[b]+', HAM= '+HAM[ih]+' (quadratic poly_fit)'
                title[2]=band_name[b]+', HAM= '+HAM[ih]+' (cubic poly_fit)'
            ENDIF
            IF band_type[b] EQ 1 THEN BEGIN
                title1=band_name[b]+SS[is]+': dn vs dL_BCS'
                title[0]=band_name[b]+SS[is]+', '+'HAM= '+HAM[ih]+' (linear poly_fit)'
                title[1]=band_name[b]+SS[is]+', '+'HAM= '+HAM[ih]+' (quadratic poly_fit)'
                title[2]=band_name[b]+SS[is]+', '+'HAM= '+HAM[ih]+' (cubic poly_fit)'
            ENDIF
            
            ; Plot dn vs dL_BCS.
            xmax=max(L_max[b,0])
            ymax=max(dn[*,b,ih,*,is,1,0])
            
            FOR j=3, 5 DO BEGIN
                plot,rad_BCS[*,b,ih,1,is,0],dn[*,b,ih,1,is,1,0],yrange=[0,ymax],xrange=[0,xmax], $
                  xtit='dL_BCS (Wm-2sr-1um-1)',ytit='dn',title=title[j-3],charsize=1.2,charthick=5,thick=3,/nodata
                
                FOR id=0, detectors[b]-1 DO BEGIN
                    oplot,rad_BCS[*,b,ih,id,is,0],dn[*,b,ih,id,is,1,0],symsize=1,color=lcol[id],psym=symbol[id],thick=3
                    IF j EQ 3 THEN oplot,rg_1[b,ih,id,is,0,j,0]+rg_1[b,ih,id,is,1,j,0]*D,color=lcol[id],thick=3
                    IF j EQ 4 THEN oplot,rg_1[b,ih,id,is,0,j,0]+rg_1[b,ih,id,is,1,j,0]*D $
                      +rg_1[b,ih,id,is,2,j,0]*D^2,color=lcol[id],thick=3
                    IF j EQ 5 THEN oplot,rg_1[b,ih,id,is,0,5,0]+rg_1[b,ih,id,is,1,j,0]*D $
                      +rg_1[b,ih,id,is,2,j,0]*D^2+rg_1[b,ih,id,is,3,j,0]*D^3,color=lcol[id],thick=3
                ENDFOR
                oplot,[L_max[b,0],L_max[b,0]],[-100,10000],symsize=1,color=lcol[1],linestyle=2,thick=3
                oplot,[L_typ[b,0],L_typ[b,0]],[-100,10000],symsize=1,color=lcol[2],linestyle=2,thick=3
                oplot,[L_min[b,0],L_min[b,0]],[-100,10000],symsize=1,color=lcol[3],linestyle=2,thick=3
                
                ; Plot fractional fitting residual in percent.
                xmax2=max(L_max[b,0])
                ymax3=max(100.*dL_fit[*,b,ih,0:detectors[b]-1,0,j,0]/dn[*,b,ih,0:detectors[b]-1,is,1,0],min=ymin3)
                
                plot,rad_BCS[*,b,ih,0,is,0],100.*dL_fit[*,b,ih,0,is,j,0]/dn[*,b,ih,0,is,1,0],xtit='dL_BCS (Wm-2sr-1um-1)',ytit='dn Residual (%)', $
                  xrange=[0,xmax2],yrange=[ymin3,ymax3],title=title[j-3],charsize=1.2,charthick=5,thick=3,/nodata
                
                FOR id=0, detectors[b]-1 DO BEGIN
                    oplot,rad_BCS[*,b,ih,id,is,0],100.*dL_fit[*,b,ih,id,is,j,0]/dn[*,b,ih,id,is,1,0],symsize=1,color=lcol[id],psym=symbol[id],thick=3
                    oplot,rad_BCS[*,b,ih,id,is,0],100.*dL_fit[*,b,ih,id,is,j,0]/dn[*,b,ih,id,is,1,0],color=lcol[id],thick=3
                ENDFOR
                oplot,[L_max[b,0],L_max[b,0]],[-100,10000],symsize=1,color=lcol[1],linestyle=2,thick=3
                oplot,[L_typ[b,0],L_typ[b,0]],[-100,10000],symsize=1,color=lcol[2],linestyle=2,thick=3
                oplot,[L_min[b,0],L_min[b,0]],[-100,10000],symsize=1,color=lcol[3],linestyle=2,thick=3
            ENDFOR
            XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
            IF band_type[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
            IF band_type[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
        ENDFOR
    ENDFOR
ENDFOR

device,/close

;*****************************************************************************
;  Plot SNR versus delta BCS radiance with (cubic polynomial) fits and residuals.
;*****************************************************************************

set_multicolor,xsave,ysave,psave,chname,lcol,symbol,red,green,blue
set_plot,'ps'
outfname=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.SNR.ps'
device,/landscape,filename=outfname,/color

!p.multi=[0,1,2]

; Plot the SNR vs dL_BCS for the weighted function along with the corresponding fitting
; residual on one page.  
FOR b=0, nbands-1 DO BEGIN
    !p.position=0

    FOR is=0, subsets[b]-1 DO BEGIN
        FOR ih=0, nham-1 DO BEGIN
            IF band_type[b] EQ 0 THEN BEGIN
                title1=band_name[b]+': SNR vs dL_BCS (powell)'
                title2=band_name[b]+', HAM= '+HAM[ih]+' (weighted function)'
            ENDIF
            IF band_type[b] EQ 1 THEN BEGIN
                title1=band_name[b]+SS[is]+': SNR vs dL_BCS (powell)'
                title2=band_name[b]+SS[is]+', '+'HAM= '+HAM[ih]+' (weighted function)'
            ENDIF
            
            ymax=max(SNR[*,b,ih,*,is,1])
            
            ; Plot the SNR vs dl_BCS..
            plot,rad_BCS[*,b,ih,0,is,0],SNR[*,b,ih,1,is,1],yrange=[0,ymax],xrange=[0,L_max[b,0]], $
              xtit='dL_BCS (Wm-2sr-1um-1)',ytit='SNR',title=title2,charsize=1.2,charthick=5,thick=3,/nodata
                    
            F[*]=0.1*E[*]
            FOR id=0, detectors[b]-1 DO BEGIN
                oplot,rad_BCS[*,b,ih,id,is,0],SNR[*,b,ih,id,is,1],symsize=1,color=lcol[id],psym=symbol[id],thick=3
                oplot,F[*],F[*]/sqrt(snr_1[b,ih,id,is,0,0,1,0]+snr_1[b,ih,id,is,1,0,1,0]*F[*]+snr_1[b,ih,id,is,2,0,1,0]*F[*]^2),color=lcol[id],thick=3
            ENDFOR
            oplot,[L_max[b,0],L_max[b,0]],[-100,10000],symsize=1,color=lcol[1],linestyle=2,thick=3
            oplot,[L_typ[b,0],L_typ[b,0]],[-100,10000],symsize=1,color=lcol[2],linestyle=2,thick=3
            oplot,[L_min[b,0],L_min[b,0]],[-100,10000],symsize=1,color=lcol[3],linestyle=2,thick=3

            XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
            IF band_type[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
            IF band_type[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
            
            ; Plot the fitting residual.
            plot,rad_BCS[*,b,ih,0,is,0],snr_fit[*,b,ih,0,is,0,1,0],xtit='dL_BCS (Wm-2sr-1um-1)', $
              ytit='SNR Fitting Residual',xrange=[0,L_max[b,0]],yrange=[-0.5,0.5],title=title2,charsize=1.2,charthick=5,thick=3,/nodata
            
            FOR id=0, detectors[b]-1 DO BEGIN
                oplot,rad_BCS[*,b,ih,id,is,0],snr_fit[*,b,ih,id,is,0,1,0],symsize=1,color=lcol[id],psym=symbol[id],thick=3
                oplot,rad_BCS[*,b,ih,id,is,0],snr_fit[*,b,ih,id,is,0,1,0],color=lcol[id],thick=3
            ENDFOR
            oplot,[L_max[b,0],L_max[b,0]],[-100,10000],symsize=1,color=lcol[1],linestyle=2,thick=3
            oplot,[L_typ[b,0],L_typ[b,0]],[-100,10000],symsize=1,color=lcol[2],linestyle=2,thick=3
            oplot,[L_min[b,0],L_min[b,0]],[-100,10000],symsize=1,color=lcol[3],linestyle=2,thick=3
            
            XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
            IF band_type[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
            IF band_type[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
        ENDFOR
    ENDFOR
ENDFOR

!p.multi=[0,2,2]

; Plot the SNR vs dL_BCS for the weighted and non-weighted function as
; well as quadratic, all one one page. The corresponding fitting
; residuals are plotted on the next page.  
FOR b=0, nbands-1 DO BEGIN
    !p.position=0

    FOR is=0, subsets[b]-1 DO BEGIN
        FOR ih=0, nham-1 DO BEGIN
            IF band_type[b] EQ 0 THEN BEGIN
                title1=band_name[b]+': SNR vs dL_BCS (powell)'
                title[0]=band_name[b]+', HAM= '+HAM[ih]+' (function)'
                title[1]=band_name[b]+', HAM= '+HAM[ih]+' (quadratic)'
                title[2]=band_name[b]+', HAM= '+HAM[ih]+' (weighted function)'
                title[3]=band_name[b]+', HAM= '+HAM[ih]+' (weighted quadratic)'
            ENDIF
            IF band_type[b] EQ 1 THEN BEGIN
                title1=band_name[b]+SS[is]+': SNR vs dL_BCS (powell)'
                title[0]=band_name[b]+SS[is]+', '+'HAM= '+HAM[ih]+' (function)'
                title[1]=band_name[b]+SS[is]+', '+'HAM= '+HAM[ih]+' (quadratic)'
                title[2]=band_name[b]+SS[is]+', '+'HAM= '+HAM[ih]+' (weighted function)'
                title[3]=band_name[b]+SS[is]+', '+'HAM= '+HAM[ih]+' (weighted quadratic)'
            ENDIF
            
            ymax=max(SNR[*,b,ih,*,is,1])
            xmax=max(L_max[b,0])
            
            ; Plot the SNR vs dl_BCS..
            j=0
            FOR ifit=0, 1 DO BEGIN
                FOR ifit2=0, 1 DO BEGIN
                    plot,rad_BCS[*,b,ih,0,is,0],SNR[*,b,ih,1,is,1],yrange=[0,ymax],xrange=[0,xmax], $
                      xtit='dL_BCS (Wm-2sr-1um-1)',ytit='SNR',title=title[j],charsize=1.2,charthick=5,thick=3,/nodata
                    
                    F[*]=0.1*E[*]
                    FOR id=0, detectors[b]-1 DO BEGIN
                        oplot,rad_BCS[*,b,ih,id,is,0],SNR[*,b,ih,id,is,1],symsize=1,color=lcol[id],psym=symbol[id],thick=3
                        IF ifit2 EQ 0 THEN oplot,F[*],F[*] $
                          /sqrt(snr_1[b,ih,id,is,0,ifit2,ifit,0]+snr_1[b,ih,id,is,1,ifit2,ifit,0]*F[*]+snr_1[b,ih,id,is,2,ifit2,ifit,0]*F[*]^2),color=lcol[id],thick=3
                        IF ifit2 EQ 1 THEN oplot,F[*],snr_1[b,ih,id,is,0,ifit2,ifit,0] $
                          +snr_1[b,ih,id,is,1,ifit2,ifit,0]*F[*]+snr_1[b,ih,id,is,2,ifit2,ifit,0]*F[*]^2,color=lcol[id],thick=3
                    ENDFOR
                    oplot,[L_max[b,0],L_max[b,0]],[-100,10000],symsize=1,color=lcol[1],linestyle=2,thick=3
                    oplot,[L_typ[b,0],L_typ[b,0]],[-100,10000],symsize=1,color=lcol[2],linestyle=2,thick=3
                    oplot,[L_min[b,0],L_min[b,0]],[-100,10000],symsize=1,color=lcol[3],linestyle=2,thick=3
                    j=j+1
                ENDFOR
            ENDFOR
            XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
            IF band_type[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
            IF band_type[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
            
            ; Plot the fitting residual.
            j=0
            FOR ifit=0, 1 DO BEGIN
                FOR ifit2=0, 1 DO BEGIN
                    plot,rad_BCS[*,b,ih,0,is,0],snr_fit[*,b,ih,0,is,1,ifit,0],xtit='dL_BCS (Wm-2sr-1um-1)', $
                      ytit='SNR Fitting Residual',xrange=[0,xmax],yrange=[-0.5,0.5],title=title[j],charsize=1.2,charthick=5,thick=3,/nodata
                    
                    FOR id=0, detectors[b]-1 DO BEGIN
                        oplot,rad_BCS[*,b,ih,id,is,0],snr_fit[*,b,ih,id,is,ifit2,ifit,0],symsize=1,color=lcol[id],psym=symbol[id],thick=3
                        oplot,rad_BCS[*,b,ih,id,is,0],snr_fit[*,b,ih,id,is,ifit2,ifit,0],color=lcol[id],thick=3
                    ENDFOR
                    oplot,[L_max[b,0],L_max[b,0]],[-100,10000],symsize=1,color=lcol[1],linestyle=2,thick=3
                    oplot,[L_typ[b,0],L_typ[b,0]],[-100,10000],symsize=1,color=lcol[2],linestyle=2,thick=3
                    oplot,[L_min[b,0],L_min[b,0]],[-100,10000],symsize=1,color=lcol[3],linestyle=2,thick=3
                    j=j+1
                ENDFOR
            ENDFOR
            XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
            IF band_type[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
            IF band_type[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
        ENDFOR
    ENDFOR
ENDFOR

device,/close

;*****************************************************************************
;  NEdT.
;*****************************************************************************

set_multicolor,xsave,ysave,psave,chname,lcol,symbol,red,green,blue
set_plot,'ps'
outfname=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.NEdT.ps'
device,/landscape,filename=outfname,/color

!p.multi=[0,3,3]
!p.position=0

NEDT_spec=[[2.5,1.5,0.396,0.107,0.091,0.07,0.072,0.072],[0,0,0,0.423,0,0,0,0]]

; NEdT at T_typ vs detector.
title1='NEdT at T_typ vs Detector'
FOR b=0, nbands-1 DO BEGIN
    plot,D[0:detectors[b]-1]+1,NEdT_typ[b,0,0:detectors[b]-1,0,0,1,0],xtit='detector',ytit='NEdT at T_typ', $
      yrange=[0,NEDT_spec[b,0]*1.1],xrange=[0,detectors[b]+2],title=band_name[b],charsize=1.2,charthick=5,thick=3,/nodata

    j=0
    FOR is=0, subsets[b]-1 DO BEGIN
        FOR ih=0, nham-1 DO BEGIN
            oplot,D[0:detectors[b]-1]+1,NEdT_typ[b,ih,0:detectors[b]-1,is,0,1,0],symsize=1,color=lcol[j],psym=symbol[j],thick=3
            oplot,D[0:detectors[b]-1]+1,NEdT_typ[b,ih,0:detectors[b]-1,is,0,1,0],color=lcol[j],thick=3

            oplot,[0,40],[NEDT_spec[b,0],NEDT_spec[b,0]],symsize=1,color=lcol[3],linestyle=2,thick=3
            j=j+1
        ENDFOR
    ENDFOR
ENDFOR
XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
set_legend,1,HAM_SS,lcol,symbol

!p.multi=[0,1,1]

; NEdT vs dL_BCS for the weighted function, one plot per page.
FOR b=0, nbands-1 DO BEGIN
    !p.position=0

    FOR is=0, subsets[b]-1 DO BEGIN
        FOR ih=0, nham-1 DO BEGIN
            IF band_type[b] EQ 0 THEN BEGIN
                title1=band_name[b]+': NEdT vs dL_BCS (powell)'
                title2=band_name[b]+', HAM= '+HAM[ih]+' (weighted function)'
            ENDIF
            IF band_type[b] EQ 1 THEN BEGIN
                title1=band_name[b]+SS[is]+': NEdT vs dL_BCS (powell)'
                title2=band_name[b]+SS[is]+', '+'HAM= '+HAM[ih]+' (weighted function)'
            ENDIF
            
            plot,rad_BCS[*,b,ih,0,is],NEdT[*,b,ih,0,is,0,1],xtit='dL_BCS (Wm-2sr-1um-1)',ytit='NEdT', $
              yrange=[0,1.0],xrange=[0,L_max[b,0]],title=title2,charsize=1.2,charthick=5,thick=3,/nodata
            
            FOR id=0, detectors[b]-1 DO BEGIN
                oplot,rad_BCS[*,b,ih,id,is],NEdT[*,b,ih,id,is,0,1],symsize=1,color=lcol[id],psym=symbol[id],thick=3
                oplot,rad_BCS[*,b,ih,id,is],NEdT[*,b,ih,id,is,0,1],color=lcol[id],thick=3
            ENDFOR
            oplot,[L_max[b,0],L_max[b,0]],[-100,100],symsize=1,color=lcol[1],linestyle=2,thick=3
            oplot,[L_typ[b,0],L_typ[b,0]],[-100,100],symsize=1,color=lcol[2], linestyle=2,thick=3
            oplot,[L_min[b,0],L_min[b,0]],[-100,100],symsize=1,color=lcol[3],linestyle=2,thick=3
            
            XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
            IF band_type[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
            IF band_type[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
        ENDFOR
    ENDFOR
ENDFOR

!p.multi=[0,2,2]

; NEdT vs dL_BCS for the weighted function, four plots per page.
FOR b=0, nbands-1 DO BEGIN
    !p.position=0

    FOR is=0, subsets[b]-1 DO BEGIN
        FOR ih=0, nham-1 DO BEGIN
            IF band_type[b] EQ 0 THEN BEGIN
                title1=band_name[b]+': NEdT vs dL_BCS (powell)'
                title[0]=band_name[b]+', HAM= '+HAM[ih]+' (function)'
                title[1]=band_name[b]+', HAM= '+HAM[ih]+' (quadratic)'
                title[2]=band_name[b]+', HAM= '+HAM[ih]+' (weighted function)'
                title[3]=band_name[b]+', HAM= '+HAM[ih]+' (weighted quadratic)'
            ENDIF
            IF band_type[b] EQ 1 THEN BEGIN
                title1=band_name[b]+SS[is]+': NEdT vs dL_BCS (powell)'
                title[0]=band_name[b]+SS[is]+', '+'HAM= '+HAM[ih]+' (function)'
                title[1]=band_name[b]+SS[is]+', '+'HAM= '+HAM[ih]+' (quadratic)'
                title[2]=band_name[b]+SS[is]+', '+'HAM= '+HAM[ih]+' (weighted function)'
                title[3]=band_name[b]+SS[is]+', '+'HAM= '+HAM[ih]+' (weighted quadratic)'
            ENDIF
            
            j=0
            FOR ifit=0, 1 DO BEGIN
                FOR ifit2=0, 1 DO BEGIN
                    plot,rad_BCS[*,b,ih,0,is],NEdT[*,b,ih,0,is,1,ifit],xtit='dL_BCS (Wm-2sr-1um-1)',ytit='NEdT', $
                      yrange=[0,1.0],xrange=[0,L_max[b,0]],title=title[j],charsize=1.2,charthick=5,thick=3,/nodata
                    
                    FOR id=0, detectors[b]-1 DO BEGIN
                        oplot,rad_BCS[*,b,ih,id,is],NEdT[*,b,ih,id,is,ifit2,ifit],symsize=1,color=lcol[id],psym=symbol[id],thick=3
                        oplot,rad_BCS[*,b,ih,id,is],NEdT[*,b,ih,id,is,ifit2,ifit],color=lcol[id],thick=3
                    ENDFOR
                    oplot,[L_max[b,0],L_max[b,0]],[-100,100],symsize=1,color=lcol[1],linestyle=2,thick=3
                    oplot,[L_typ[b,0],L_typ[b,0]],[-100,100],symsize=1,color=lcol[2], linestyle=2,thick=3
                    oplot,[L_min[b,0],L_min[b,0]],[-100,100],symsize=1,color=lcol[3],linestyle=2,thick=3
                    j=j+1
                ENDFOR
            ENDFOR
            XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
            IF band_type[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
            IF band_type[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
        ENDFOR
    ENDFOR
ENDFOR

device,/close

;*****************************************************************************
;  Radiometric response characterization uncertainty (RRCU) (SRV0448).
;*****************************************************************************

set_multicolor,xsave,ysave,psave,chname,lcol,symbol,red,green,blue
set_plot,'ps'
outfname=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.RRCU.ps'
device,/landscape,filename=outfname,/color

!p.multi=[0,1,1]

; Plot the RRCU, one band per page.
title1='RRCU vs Detector (SRV0448)'
FOR b=0, nbands-1 DO BEGIN
    !p.position=0
    
    title2=band_name[b]
        
    ymax=max(rrcu[b,*,0:detectors[b]-1,*,*,0,0])
    IF ymax LT 0.001 THEN ymax=0.0011
    plot,E[0:detectors[b]-1]+1,rrcu[b,0,0:detectors[b]-1,0,1,0,0],xtit='Detectors',ytit='RRCU',xrange=[0,detectors[b]+2],yrange=[0,ymax],title=title2, $
      charsize=1.2,charthick=5,thick=3,/nodata
        
    j=0
    FOR is=0, subsets[b]-1 DO BEGIN
        FOR ih=0, nham-1 DO BEGIN
            oplot,E[0:detectors[b]-1]+1,rrcu[b,ih,0:detectors[b]-1,is,1,0,0],symsize=1,color=lcol[j],psym=symbol[j],thick=3
            oplot,E[0:detectors[b]-1]+1,rrcu[b,ih,0:detectors[b]-1,is,1,0,0],color=lcol[j],thick=3
            j=j+1
        ENDFOR
    ENDFOR
    oplot,[0,100],[0.001,0.001],color=lcol[1],linestyle=2,thick=3
    
    XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
    set_legend,1,HAM_SS,lcol,symbol
ENDFOR

!p.multi=[0,2,2]

; Plot the RRCU, four bands per page.
FOR b=0, nbands-1 DO BEGIN
    !p.position=0
        
    title2=band_name[b]
    
    ymax=max(rrcu[b,*,0:detectors[b]-1,*,*,0,0])
    IF ymax LT 0.001 THEN ymax=0.0011
    plot,E[0:detectors[b]-1]+1,rrcu[b,0,0:detectors[b]-1,0,1,0,0],xtit='Detectors',ytit='RRCU',xrange=[0,detectors[b]+2],yrange=[0,ymax],title=title2, $
      charsize=1.2,charthick=5,thick=3,/nodata

    j=0
    FOR is=0, subsets[b]-1 DO BEGIN
        FOR ih=0, nham-1 DO BEGIN
            oplot,E[0:detectors[b]-1]+1,rrcu[b,ih,0:detectors[b]-1,is,1,0,0],symsize=1,color=lcol[j],psym=symbol[j],thick=3
            oplot,E[0:detectors[b]-1]+1,rrcu[b,ih,0:detectors[b]-1,is,1,0,0],color=lcol[j],thick=3
            j=j+1
        ENDFOR
    ENDFOR
    oplot,[0,100],[0.001,0.001],color=lcol[1],linestyle=2,thick=3
    
    XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
ENDFOR

device,/close

;*****************************************************************************
;  Radiometric response non-linearity (RRNL) (SRV0595).
;*****************************************************************************

set_multicolor,xsave,ysave,psave,chname,lcol,symbol,red,green,blue
set_plot,'ps'
outfname=outpath+a2[a3-3]+'.'+a2[a3-2]+'.'+a2[a3-1]+'.RRNL.ps'
device,/landscape,filename=outfname,/color

!p.multi=[0,1,1]

; Plot the RRNL, one band per page.
title1='RRNL vs Detector (SRV0595)'
FOR b=0, nbands-1 DO BEGIN
    !p.position=0

    title2=band_name[b]+' (linear poly_fit)'

    ymax=max(rrnl[b,*,*,*,3,0])
    IF ymax LT 0.01 AND band_type[b] EQ 0 THEN ymax=0.011
    IF ymax LT 0.01 AND band_type[b] EQ 1 THEN ymax=0.013

    plot,E[0:detectors[b]-1]+1,rrnl[b,0,0:detectors[b]-1,0,3,0],xtit='Detectors',ytit='RRNL',xrange=[0,detectors[b]+2],yrange=[0,ymax],title=title2, $
      charsize=1.2,charthick=5,thick=3,/nodata

    j=0
    FOR is=0, subsets[b]-1 DO BEGIN
        FOR ih=0, nham-1 DO BEGIN
            oplot,E[0:detectors[b]-1]+1,rrnl[b,ih,0:detectors[b]-1,is,3,0],symsize=1,color=lcol[j],psym=symbol[j],thick=3
            oplot,E[0:detectors[b]-1]+1,rrnl[b,ih,0:detectors[b]-1,is,3,0],color=lcol[j],thick=3
            j=j+1
        ENDFOR
    ENDFOR
    oplot,[0,100],[0.01,0.01],color=lcol[1],linestyle=2,thick=3

    XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
    set_legend,1,HAM_SS,lcol,symbol
ENDFOR

!p.multi=[0,2,2]
!p.position=0

; Plot the RRNL, four bands per page.
FOR b=0, nbands-1 DO BEGIN
    title2=band_name[b]+' (linear poly_fit)'

    ymax=max(rrnl[b,*,*,*,3,0])
    IF ymax LT 0.01 AND band_type[b] EQ 0 THEN ymax=0.011
    IF ymax LT 0.01 AND band_type[b] EQ 1 THEN ymax=0.013
    
    plot,E[0:detectors[b]-1]+1,rrnl[b,0,0:detectors[b]-1,0,3,0],xtit='Detectors',ytit='RRNL',xrange=[0,detectors[b]+2],yrange=[0,ymax],title=title2, $
      charsize=1.2,charthick=5,thick=3,/nodata
    
    j=0
    FOR is=0, subsets[b]-1 DO BEGIN
        FOR ih=0, nham-1 DO BEGIN
            oplot,E[0:detectors[b]-1]+1,rrnl[b,ih,0:detectors[b]-1,is,3,0],symsize=1,color=lcol[j],psym=symbol[j],thick=3
            oplot,E[0:detectors[b]-1]+1,rrnl[b,ih,0:detectors[b]-1,is,3,0],color=lcol[j],thick=3
            j=j+1
        ENDFOR
    ENDFOR
    oplot,[0,100],[0.01,0.01],color=lcol[1],linestyle=2,thick=3
    
    XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
    set_legend,1,HAM_SS,lcol,symbol
ENDFOR

device,/close

skip_loop:

END
